==> dl.php?src=linea21_1_6.zip: linea21/project/sup.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage project
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id;


if(isset($_POST['valider'])) {
  $project_object = new project;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$project_object->DeleteProject($id, $sql_object);
  if($result) header("Location: ".$link_confirm);
  else  system_error();
}

$query= SQL_getProjectName($id);
$result=$sql_object->DBSelect($query);
$project_name=FormatText($result[0]['project_name']);
$project_owner=FormatText($result[0]['project_posted_by']);

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('project')) ReloadIndex('admin');
if ($l21auth->GetSessionElement('id')!= $project_owner && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////
?>

<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','project'); ?></a></li>
	<li><span><?php echo formatNavTitle(_t('project','sup')." : ". $project_name); ?></span></li>
</ul>
</div>
<!--end barre haute -->
<?php
include_once(THEME_ADMIN_PATH."quickicons.php");
?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php echo "<h2>". formatTitleh2($project_name)."</h2>"; ?>
<form id="suptheme" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<p class="info"><?php echo _t('divers','sup_confirm'); ?></p>
	<div>
		<input name="id" type="hidden" value="<?php echo $id; ?>" />
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<?php echo cancel_button('javascript:history.go(-1);'); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid'); ?>" class="button" id="valider" />
	</div>
</form>
</div>
<?php include_once(override($dir.'/help.php', THEME_ADMIN_PATH)); ?>
</div>

==> dl.php?src=linea21_1_7.zip: linea21/project/sup.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage project
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id;


if(isset($_POST['valider'])) {
  $project_object = new project;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$project_object->DeleteProject($id, $sql_object);
  if($result) header("Location: ".$link_confirm);
  else  system_error();
}

$query= SQL_getProjectName($id);
$result=$sql_object->DBSelect($query);
$project_name=FormatText($result[0]['project_name']);
$project_owner=FormatText($result[0]['project_posted_by']);

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('project')) ReloadIndex('admin');
if ($l21auth->GetSessionElement('id')!= $project_owner && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////
?>

<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','project'); ?></a></li>
	<li><span><?php echo formatNavTitle(_t('project','sup')." : ". $project_name); ?></span></li>
</ul>
</div>
<!--end barre haute -->
<?php
include_once(THEME_ADMIN_PATH."quickicons.php");
?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php echo "<h2>". formatTitleh2($project_name)."</h2>"; ?>
<form id="suptheme" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<p class="info"><i class="icon-trash"></i> <?php echo _t('divers','sup_confirm'); ?></p>
	<div>
		<input name="id" type="hidden" value="<?php echo $id; ?>" />
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<?php echo cancel_button('javascript:history.go(-1);'); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid'); ?>" class="button" id="valider" />
	</div>
</form>
</div>
<?php include_once(override($dir.'/help.php', THEME_ADMIN_PATH)); ?>
</div>
